==> blancoNLpackGenerator-0.0.34-src.zip: src/blanco/nlpack/generator/task/BlancoNLpackGeneratorPluginDirectory2JarProcessImpl.java <==
/*******************************************************************************
 * Copyright (c) 2008 IGA Tosiki, NTT DATA BUSINESS BRAINS Corp.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    IGA Tosiki (NTT DATA BUSINESS BRAINS Corp.) - initial API and implementation
 *******************************************************************************/
/*
 * blanco Framework
 * Copyright (C) 2008 NTT DATA BUSINESS BRAINS CORPORATION
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.nlpack.generator.task;

import java.io.IOException;

import blanco.nlpack.generator.BlancoNLpackGeneratorPluginDirectory2Jar;
import blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorPluginDirectory2JarProcessInput;

/**
 * Ant^XNublancoNLpackGeneratorPluginDirectory2JarṽGg|CgB
 * 
 * @author IGA Tosiki
 */
public class BlancoNLpackGeneratorPluginDirectory2JarProcessImpl implements
        BlancoNLpackGeneratorPluginDirectory2JarProcess {

    /**
     * NXCX^Xďsۂ̃Gg|CgłB
     * 
     * @param input
     *            ̓̓p[^B
     * @return ̎sʁB
     * @throws IOException
     *             o͗OꍇB
     * @throws IllegalArgumentException
     *             ͒lɕsꍇB
     */
    public int execute(
            final BlancoNLpackGeneratorPluginDirectory2JarProcessInput input)
            throws IOException, IllegalArgumentException {
        final BlancoNLpackGeneratorPluginDirectory2Jar processor = new BlancoNLpackGeneratorPluginDirectory2Jar();
        processor.process(input);

        return BlancoNLpackGeneratorPluginDirectory2JarBatchProcess.END_SUCCESS;
    }
}

==> blancoNLpackGenerator-0.1.21-src.zip: src/blanco/nlpack/generator/task/BlancoNLpackGeneratorPluginDirectory2JarProcessImpl.java <==
/*******************************************************************************
 * Copyright (c) 2008 IGA Tosiki, NTT DATA BUSINESS BRAINS Corp.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    IGA Tosiki (NTT DATA BUSINESS BRAINS Corp.) - initial API and implementation
 *******************************************************************************/
/*
 * blanco Framework
 * Copyright (C) 2008 NTT DATA BUSINESS BRAINS CORPORATION
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.nlpack.generator.task;

import java.io.File;
import java.io.IOException;

import blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorPluginDirectory2JarProcessInput;
import blanco.properties.BlancoPropertiesDirectory2Jar;

/**
 * Ant^XNublancoNLpackGeneratorPluginDirectory2JarṽGg|CgB
 * 
 * @author IGA Tosiki
 */
public class BlancoNLpackGeneratorPluginDirectory2JarProcessImpl implements
        BlancoNLpackGeneratorPluginDirectory2JarProcess {

    /**
     * NXCX^Xďsۂ̃Gg|CgłB
     * 
     * @param input
     *            ̓̓p[^B
     * @return ̎sʁB
     * @throws IOException
     *             o͗OꍇB
     * @throws IllegalArgumentException
     *             ͒lɕsꍇB
     */
    public int execute(
            final BlancoNLpackGeneratorPluginDirectory2JarProcessInput input)
            throws IOException, IllegalArgumentException {
        final BlancoPropertiesDirectory2Jar processor = new BlancoPropertiesDirectory2Jar();
        processor.process(new File(input.getSourcedir()), new File(input
                .getTargetdir()));

        return BlancoNLpackGeneratorPluginDirectory2JarBatchProcess.END_SUCCESS;
    }
}
